RwHashMap

Struct RwHashMap 

pub struct RwHashMap<Key: Hash + Eq> { /* private fields */ }

Implementations

Source

impl<Key: Hash + Eq> RwHashMap<Key>

pub fn new() -> Self

pub fn get<T: 'static + Any + Send>( &self, key: &Key, ) -> Option<MapReader<'_, T>>

pub fn get_mut<T: 'static + Any + Send>( &self, key: &Key, ) -> Option<MapWriter<'_, T>>

pub fn insert<T: 'static + Any + Send>(&self, key: Key, value: T) -> Option<()>

pub unsafe fn get_mut_nonlock<T: 'static + Any + Send>( &self, key: &Key, ) -> Option<&mut T>

Safety

This function does not lock the table or the field, so it is up to the caller to ensure that no other threads are accessing the table or the field while this function is being called.